@@ -13,8 +13,6 @@ then
 	echo "And reload nginx, run # /etc/init.d/nginx reload"
 fi
 
-echo "To stop diaspora, run # /etc/init.d/diaspora stop"
-echo "To see the service status, run # /etc/init.d/diaspora status"
-echo "To start diaspora service, run # /etc/init.d/diaspora start"
+echo "Debian specific documentation is available at /usr/share/doc/diaspora-common/README"
 
 echo "Visit your pod at $ENVIRONMENT_URL"
